==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/SettingsPropertiesCacheArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.SettingsPropertiesCacheArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property channel Indicates the account type. Allowed values include: EA, PAYG, Modern, Internal, Unknown.
 * @property id Resource ID used by Resource Manager to uniquely identify the scope.
 * @property name Display name for the scope.
 * @property parent Resource ID of the parent scope. For instance, subscription's resource ID for a resource group or a management group resource ID for a subscription.
 * @property status Indicates the status of the scope. Status only applies to subscriptions and billing accounts.
 * @property subchannel Indicates the type of modern account. Allowed values include: Individual, Enterprise, Partner, Indirect, NotApplicable
 */
public data class SettingsPropertiesCacheArgs(
    public val channel: Output<String>,
    public val id: Output<String>,
    public val name: Output<String>,
    public val parent: Output<String>? = null,
    public val status: Output<String>? = null,
    public val subchannel: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.SettingsPropertiesCacheArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.SettingsPropertiesCacheArgs =
        com.pulumi.azurenative.costmanagement.inputs.SettingsPropertiesCacheArgs.builder()
            .channel(channel.applyValue({ args0 -> args0 }))
            .id(id.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .parent(parent?.applyValue({ args0 -> args0 }))
            .status(status?.applyValue({ args0 -> args0 }))
            .subchannel(subchannel.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SettingsPropertiesCacheArgs].
 */
@PulumiTagMarker
public class SettingsPropertiesCacheArgsBuilder internal constructor() {
    private var channel: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var parent: Output<String>? = null

    private var status: Output<String>? = null

    private var subchannel: Output<String>? = null

    /**
     * @param value Indicates the account type. Allowed values include: EA, PAYG, Modern, Internal, Unknown.
     */
    @JvmName("dubemiqbceelhdql")
    public suspend fun channel(`value`: Output<String>) {
        this.channel = value
    }

    /**
     * @param value Resource ID used by Resource Manager to uniquely identify the scope.
     */
    @JvmName("tmmlotnpvxayqunu")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Display name for the scope.
     */
    @JvmName("kpeovutmrqfhjdrv")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Resource ID of the parent scope. For instance, subscription's resource ID for a resource group or a management group resource ID for a subscription.
     */
    @JvmName("yalmhiwfbhiwtlqr")
    public suspend fun parent(`value`: Output<String>) {
        this.parent = value
    }

    /**
     * @param value Indicates the status of the scope. Status only applies to subscriptions and billing accounts.
     */
    @JvmName("okksuravgwdvrbou")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Indicates the type of modern account. Allowed values include: Individual, Enterprise, Partner, Indirect, NotApplicable
     */
    @JvmName("gxwngbxarlnebbfy")
    public suspend fun subchannel(`value`: Output<String>) {
        this.subchannel = value
    }

    /**
     * @param value Indicates the account type. Allowed values include: EA, PAYG, Modern, Internal, Unknown.
     */
    @JvmName("unydyhphuxkubvkd")
    public suspend fun channel(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.channel = mapped
    }

    /**
     * @param value Resource ID used by Resource Manager to uniquely identify the scope.
     */
    @JvmName("eqyuilmmyyxqnwns")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Display name for the scope.
     */
    @JvmName("lqkhjnjvkhhlulol")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Resource ID of the parent scope. For instance, subscription's resource ID for a resource group or a management group resource ID for a subscription.
     */
    @JvmName("epqjewhibdobyqke")
    public suspend fun parent(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parent = mapped
    }

    /**
     * @param value Indicates the status of the scope. Status only applies to subscriptions and billing accounts.
     */
    @JvmName("paldtpndnyihxqlx")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Indicates the type of modern account. Allowed values include: Individual, Enterprise, Partner, Indirect, NotApplicable
     */
    @JvmName("krxuwuyvhrlwpych")
    public suspend fun subchannel(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subchannel = mapped
    }

    internal fun build(): SettingsPropertiesCacheArgs = SettingsPropertiesCacheArgs(
        channel = channel ?: throw PulumiNullFieldException("channel"),
        id = id ?: throw PulumiNullFieldException("id"),
        name = name ?: throw PulumiNullFieldException("name"),
        parent = parent,
        status = status,
        subchannel = subchannel ?: throw PulumiNullFieldException("subchannel"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/SettingsPropertiesCacheArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.SettingsPropertiesCacheArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property channel Indicates the account type. Allowed values include: EA, PAYG, Modern, Internal, Unknown.
 * @property id Resource ID used by Resource Manager to uniquely identify the scope.
 * @property name Display name for the scope.
 * @property parent Resource ID of the parent scope. For instance, subscription's resource ID for a resource group or a management group resource ID for a subscription.
 * @property status Indicates the status of the scope. Status only applies to subscriptions and billing accounts.
 * @property subchannel Indicates the type of modern account. Allowed values include: Individual, Enterprise, Partner, Indirect, NotApplicable
 */
public data class SettingsPropertiesCacheArgs(
    public val channel: Output<String>,
    public val id: Output<String>,
    public val name: Output<String>,
    public val parent: Output<String>? = null,
    public val status: Output<String>? = null,
    public val subchannel: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.SettingsPropertiesCacheArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.SettingsPropertiesCacheArgs =
        com.pulumi.azurenative.costmanagement.inputs.SettingsPropertiesCacheArgs.builder()
            .channel(channel.applyValue({ args0 -> args0 }))
            .id(id.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .parent(parent?.applyValue({ args0 -> args0 }))
            .status(status?.applyValue({ args0 -> args0 }))
            .subchannel(subchannel.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SettingsPropertiesCacheArgs].
 */
@PulumiTagMarker
public class SettingsPropertiesCacheArgsBuilder internal constructor() {
    private var channel: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var parent: Output<String>? = null

    private var status: Output<String>? = null

    private var subchannel: Output<String>? = null

    /**
     * @param value Indicates the account type. Allowed values include: EA, PAYG, Modern, Internal, Unknown.
     */
    @JvmName("mvppudbxypinmuoa")
    public suspend fun channel(`value`: Output<String>) {
        this.channel = value
    }

    /**
     * @param value Resource ID used by Resource Manager to uniquely identify the scope.
     */
    @JvmName("trhtikqpcyaybfkw")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Display name for the scope.
     */
    @JvmName("tyadkhvjgewqipdd")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Resource ID of the parent scope. For instance, subscription's resource ID for a resource group or a management group resource ID for a subscription.
     */
    @JvmName("wcawrjnevvjpvyln")
    public suspend fun parent(`value`: Output<String>) {
        this.parent = value
    }

    /**
     * @param value Indicates the status of the scope. Status only applies to subscriptions and billing accounts.
     */
    @JvmName("gvsmghfknwnglbmh")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Indicates the type of modern account. Allowed values include: Individual, Enterprise, Partner, Indirect, NotApplicable
     */
    @JvmName("rgphxfnswcejbidm")
    public suspend fun subchannel(`value`: Output<String>) {
        this.subchannel = value
    }

    /**
     * @param value Indicates the account type. Allowed values include: EA, PAYG, Modern, Internal, Unknown.
     */
    @JvmName("jhirgtqmyksfieiy")
    public suspend fun channel(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.channel = mapped
    }

    /**
     * @param value Resource ID used by Resource Manager to uniquely identify the scope.
     */
    @JvmName("qdjdryndnnxxfjvl")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Display name for the scope.
     */
    @JvmName("jqodsdtxiucdgabh")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Resource ID of the parent scope. For instance, subscription's resource ID for a resource group or a management group resource ID for a subscription.
     */
    @JvmName("qoueixpykufucuna")
    public suspend fun parent(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parent = mapped
    }

    /**
     * @param value Indicates the status of the scope. Status only applies to subscriptions and billing accounts.
     */
    @JvmName("mghlsqhgkgtvascj")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Indicates the type of modern account. Allowed values include: Individual, Enterprise, Partner, Indirect, NotApplicable
     */
    @JvmName("qdfnutbevjawdpea")
    public suspend fun subchannel(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subchannel = mapped
    }

    internal fun build(): SettingsPropertiesCacheArgs = SettingsPropertiesCacheArgs(
        channel = channel ?: throw PulumiNullFieldException("channel"),
        id = id ?: throw PulumiNullFieldException("id"),
        name = name ?: throw PulumiNullFieldException("name"),
        parent = parent,
        status = status,
        subchannel = subchannel ?: throw PulumiNullFieldException("subchannel"),
    )
}
